GraphQL in the terminal
=======================

.. image:: docs/assets/showcase.gif

Installation
------------

.. code-block:: text

   pip3 install gqt
           
Ideas
-----

- Execute or print built query.

- Contols:

  - Use ``/`` to fuzzy find field.

- Variables?

- Pipe output to other programs? Possible when using curses? How to do it?
